### 0.10.6 {small}`the future`

```{rubric} Bugfix
```

* Defer import of zarr in test helpers, as scanpy CI job relies on them {pr}`1343` {user}`ilan-gold`

```{rubric} Documentation
```

```{rubric} Performance
```
